Stan Math Library: stan/math/rev/scal/fun/log.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_LOG_HPP
2 #define STAN_MATH_REV_SCAL_FUN_LOG_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <cmath>
6
7 namespace stan {
8 namespace math {
9
10 namespace {
11 class log_vari : public op_v_vari {
12 public:
13 explicit log_vari(vari* avi) :
14 op_v_vari(std::log(avi->val_), avi) {
15 }
16 void chain() {
17 avi_->adj_ += adj_ / avi_->val_;
18 }
19 };
20 }
21
50 inline var log(const var& a) {
51 return var(new log_vari(a.vi_));
52 }
53
54 }
55 }
56 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
std
Definition: std_numeric_limits.hpp:7
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43

[ Stan Home Page ] © 2011–2016, Stan Development Team.